
# THIS FILE IS GENERATED FROM OASYS SETUP.PY
short_version = '1.2.24'
version = '1.2.24'
full_version = '1.2.24'
git_revision = '4433a9675cd8b6c77de91358c266c8b24363b5f2'
release = True

if not release:
    version = full_version
    short_version += ".dev"



# pkg_resources selects a suitable resource loader based on the modules's
# __loader__ attribute. In python2 it defaults to None, which maps to the
# default resource loader, but it python3 it does not. As a result,
# pkg_resources is unable to select a resource loader and load resources.
# By settings __loader__ to None, we workaround the pkg_resources bug.
__loader__ = None



__author__ = 'labx'
__menu__="just for discovery"

SEPARATOR = "OMENU_SEPARATOR"
OPEN_CONTAINER = "OPEN_CONTAINER"
CLOSE_CONTAINER = "CLOSE_CONTAINER"

class OMenu():

    def __init__(self, name="NewMenu"):
        self.name = name
        self.canvas_main_window=None
        self.sub_menu_names = []

    def setCanvasMainWindow(self, canvas_main_window):
        self.canvas_main_window = canvas_main_window

    def addSubMenu(self, name):
        self.sub_menu_names.append(name)

    def addSeparator(self):
        self.sub_menu_names.append(SEPARATOR)

    def openContainer(self):
        self.sub_menu_names.append(OPEN_CONTAINER)

    def closeContainer(self):
        self.sub_menu_names.append(CLOSE_CONTAINER)

    def addContainer(self, name):
        self.sub_menu_names.append(name)

    def isSeparator(self, name):
        return name == SEPARATOR

    def isOpenContainer(self, name):
        return name == OPEN_CONTAINER

    def isCloseContainer(self, name):
        return name == CLOSE_CONTAINER

    def getSubMenuNamesList(self):
        return self.sub_menu_names

